@@ -104,6 +104,14 @@ def sample_app():
     def custom_cors():
         return {'cors': True}
 
+    @demo.route('/cors-enabled-for-one-method', methods=['GET'])
+    def without_cors():
+        return {'ok': True}
+
+    @demo.route('/cors-enabled-for-one-method', methods=['POST'], cors=True)
+    def with_cors():
+        return {'ok': True}
+
     @demo.route('/options', methods=['OPTIONS'])
     def options():
         return {'options': True}
@@ -162,48 +170,49 @@ def sample_app():
 def demo_app_auth():
     demo = app.Chalice('app-name')
 
+    def _policy(effect, resource, action='execute-api:Invoke'):
+        return {
+            'context': {},
+            'principalId': 'user',
+            'policyDocument': {
+                'Version': '2012-10-17',
+                'Statement': [
+                    {
+                        'Action': action,
+                        'Effect': effect,
+                        'Resource': resource,
+                    }
+                ]
+            }
+        }
+
     @demo.authorizer()
     def auth_with_explicit_policy(auth_request):
         token = auth_request.token
         if token == 'allow':
-            return {
-                'context': {},
-                'principalId': 'user',
-                'policyDocument': {
-                    'Version': '2012-10-17',
-                    'Statement': [
-                        {
-                            'Action': 'execute-api:Invoke',
-                            'Effect': 'Allow',
-                            'Resource':
-                            ["arn:aws:execute-api:mars-west-1:123456789012:"
-                             "ymy8tbxw7b/api/GET/explicit"]
-                        }
-                    ]
-                }
-            }
+            return _policy(
+                effect='Allow', resource=[
+                    "arn:aws:execute-api:mars-west-1:123456789012:"
+                    "ymy8tbxw7b/api/GET/explicit"])
         else:
-            return {
-                'context': {},
-                'principalId': '',
-                'policyDocument': {
-                    'Version': '2012-10-17',
-                    'Statement': [
-                        {
-                            'Action': 'execute-api:Invoke',
-                            'Effect': 'Deny',
-                            'Resource':
-                            ["arn:aws:execute-api:mars-west-1:123456789012:"
-                             "ymy8tbxw7b/api/GET/explicit"]
-                        }
-                    ]
-                }
-            }
+            return _policy(
+                effect='Deny', resource=[
+                    "arn:aws:execute-api:mars-west-1:123456789012:"
+                    "ymy8tbxw7b/api/GET/explicit"])
 
     @demo.authorizer()
     def demo_authorizer_returns_none(auth_request):
         return None
 
+    @demo.authorizer()
+    def auth_with_multiple_actions(auth_request):
+        return _policy(
+            effect='Allow', resource=[
+                    "arn:aws:execute-api:mars-west-1:123456789012:"
+                    "ymy8tbxw7b/api/GET/multi"],
+            action=['execute-api:Invoke', 'execute-api:Other']
+        )
+
     @demo.authorizer()
     def demo_auth(auth_request):
         token = auth_request.token
@@ -265,6 +274,10 @@ def demo_app_auth():
     def explicit():
         return {}
 
+    @demo.route('/multi', authorizer=auth_with_multiple_actions)
+    def multi():
+        return {}
+
     @demo.route('/iam', authorizer=iam_authorizer)
     def iam_route():
         return {}
@@ -423,6 +436,26 @@ def test_non_preflight_options_request(handler):
     assert _get_body_from_response_stream(handler) == {'options': True}
 
 
+def test_preflight_request_should_succeed_even_if_cors_disabled(handler):
+    headers = {'content-type': 'application/json', 'origin': 'null'}
+    set_current_request(handler, method='OPTIONS', path='/index',
+                        headers=headers)
+    handler.do_OPTIONS()
+    response_lines = handler.wfile.getvalue().splitlines()
+    assert b'HTTP/1.1 200 OK' in response_lines
+
+
+def test_preflight_returns_correct_methods_in_access_allow_header(handler):
+    headers = {'content-type': 'application/json', 'origin': 'null'}
+    set_current_request(handler, method='OPTIONS',
+                        path='/cors-enabled-for-one-method',
+                        headers=headers)
+    handler.do_OPTIONS()
+    response_lines = handler.wfile.getvalue().splitlines()
+    assert b'HTTP/1.1 200 OK' in response_lines
+    assert b'Access-Control-Allow-Methods: POST,OPTIONS' in response_lines
+
+
 def test_errors_converted_to_json_response(handler):
     set_current_request(handler, method='GET', path='/badrequest')
     handler.do_GET()
@@ -937,6 +970,17 @@ class TestLocalBuiltinAuthorizers(object):
         with pytest.raises(NotAuthorizedError):
             authorizer.authorize(path, event, context)
 
+    def test_can_understand_multi_actions(self, demo_app_auth,
+                                          lambda_context_args,
+                                          create_event):
+        authorizer = LocalGatewayAuthorizer(demo_app_auth)
+        path = '/multi'
+        event = create_event(path, 'GET', {})
+        event['headers']['authorization'] = 'allow'
+        context = LambdaContext(*lambda_context_args)
+        event, context = authorizer.authorize(path, event, context)
+        assert event['requestContext']['authorizer']['principalId'] == 'user'
+
     def test_can_understand_cognito_token(self, lambda_context_args,
                                           demo_app_auth, create_event):
         # Ensures that / routes work since that is a special case in the
